apierrors

package
v0.16.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type APIError

type APIError struct {
	Message     string
	StatusCode  int
	Body        string
	RawResponse *http.Response
}

func NewAPIError

func NewAPIError(message string, statusCode int, body string, httpRes *http.Response) *APIError

func (*APIError) Error

func (e *APIError) Error() string

type AlreadyCanceledSubscription

type AlreadyCanceledSubscription struct {
	Error_ string `const:"AlreadyCanceledSubscription" json:"error"`
	Detail string `json:"detail"`
}

func (*AlreadyCanceledSubscription) Error

type CheckoutForbiddenError

type CheckoutForbiddenError struct {
	AlreadyActiveSubscriptionError *components.AlreadyActiveSubscriptionError `queryParam:"inline" union:"member"`
	NotOpenCheckout                *components.NotOpenCheckout                `queryParam:"inline" union:"member"`
	PaymentNotReady                *components.PaymentNotReady                `queryParam:"inline" union:"member"`
	TrialAlreadyRedeemed           *components.TrialAlreadyRedeemed           `queryParam:"inline" union:"member"`

	Type CheckoutForbiddenErrorType
}

func CreateCheckoutForbiddenErrorAlreadyActiveSubscriptionError

func CreateCheckoutForbiddenErrorAlreadyActiveSubscriptionError(alreadyActiveSubscriptionError components.AlreadyActiveSubscriptionError) CheckoutForbiddenError

func CreateCheckoutForbiddenErrorNotOpenCheckout

func CreateCheckoutForbiddenErrorNotOpenCheckout(notOpenCheckout components.NotOpenCheckout) CheckoutForbiddenError

func CreateCheckoutForbiddenErrorPaymentNotReady

func CreateCheckoutForbiddenErrorPaymentNotReady(paymentNotReady components.PaymentNotReady) CheckoutForbiddenError

func CreateCheckoutForbiddenErrorTrialAlreadyRedeemed

func CreateCheckoutForbiddenErrorTrialAlreadyRedeemed(trialAlreadyRedeemed components.TrialAlreadyRedeemed) CheckoutForbiddenError

func (CheckoutForbiddenError) Error

func (u CheckoutForbiddenError) Error() string

func (CheckoutForbiddenError) MarshalJSON

func (u CheckoutForbiddenError) MarshalJSON() ([]byte, error)

func (*CheckoutForbiddenError) UnmarshalJSON

func (u *CheckoutForbiddenError) UnmarshalJSON(data []byte) error

type CheckoutForbiddenErrorType

type CheckoutForbiddenErrorType string
const (
	CheckoutForbiddenErrorTypeAlreadyActiveSubscriptionError CheckoutForbiddenErrorType = "AlreadyActiveSubscriptionError"
	CheckoutForbiddenErrorTypeNotOpenCheckout                CheckoutForbiddenErrorType = "NotOpenCheckout"
	CheckoutForbiddenErrorTypePaymentNotReady                CheckoutForbiddenErrorType = "PaymentNotReady"
	CheckoutForbiddenErrorTypeTrialAlreadyRedeemed           CheckoutForbiddenErrorType = "TrialAlreadyRedeemed"
)

type CustomerNotReady

type CustomerNotReady struct {
	Error_ string `const:"CustomerNotReady" json:"error"`
	Detail string `json:"detail"`
}

func (*CustomerNotReady) Error

func (e *CustomerNotReady) Error() string

type CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice

type CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice struct {
	MissingInvoiceBillingDetails *components.MissingInvoiceBillingDetails `queryParam:"inline" union:"member"`
	NotPaidOrder                 *components.NotPaidOrder                 `queryParam:"inline" union:"member"`

	Type CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceType

	HTTPMeta components.HTTPMetadata `json:"-"`
}

CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice - Order is not paid or is missing billing name or address.

func CreateCustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceMissingInvoiceBillingDetails

func CreateCustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceMissingInvoiceBillingDetails(missingInvoiceBillingDetails components.MissingInvoiceBillingDetails) CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice

func (CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice) Error

func (CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice) MarshalJSON

func (*CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoice) UnmarshalJSON

type CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceType

type CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceType string
const (
	CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceTypeMissingInvoiceBillingDetails CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceType = "MissingInvoiceBillingDetails"
	CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceTypeNotPaidOrder                 CustomerPortalOrdersGenerateInvoiceResponse422CustomerPortalOrdersGenerateInvoiceType = "NotPaidOrder"
)

type ExpiredCheckoutError

type ExpiredCheckoutError struct {
	Error_ string `const:"ExpiredCheckoutError" json:"error"`
	Detail string `json:"detail"`
}

func (*ExpiredCheckoutError) Error

func (e *ExpiredCheckoutError) Error() string

type HTTPValidationError

type HTTPValidationError struct {
	Detail []components.ValidationError `json:"detail,omitempty"`
}

func (*HTTPValidationError) Error

func (e *HTTPValidationError) Error() string

type NotPermitted

type NotPermitted struct {
	Error_ string `const:"NotPermitted" json:"error"`
	Detail string `json:"detail"`
}

func (*NotPermitted) Error

func (e *NotPermitted) Error() string

type OrderNotEligibleForRetry

type OrderNotEligibleForRetry struct {
	Error_ string `const:"OrderNotEligibleForRetry" json:"error"`
	Detail string `json:"detail"`
}

func (*OrderNotEligibleForRetry) Error

func (e *OrderNotEligibleForRetry) Error() string

type OrdersGenerateInvoiceResponse422OrdersGenerateInvoice

type OrdersGenerateInvoiceResponse422OrdersGenerateInvoice struct {
	MissingInvoiceBillingDetails *components.MissingInvoiceBillingDetails `queryParam:"inline" union:"member"`
	NotPaidOrder                 *components.NotPaidOrder                 `queryParam:"inline" union:"member"`

	Type OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceType

	HTTPMeta components.HTTPMetadata `json:"-"`
}

OrdersGenerateInvoiceResponse422OrdersGenerateInvoice - Order is not paid or is missing billing name or address.

func CreateOrdersGenerateInvoiceResponse422OrdersGenerateInvoiceMissingInvoiceBillingDetails

func CreateOrdersGenerateInvoiceResponse422OrdersGenerateInvoiceMissingInvoiceBillingDetails(missingInvoiceBillingDetails components.MissingInvoiceBillingDetails) OrdersGenerateInvoiceResponse422OrdersGenerateInvoice

func CreateOrdersGenerateInvoiceResponse422OrdersGenerateInvoiceNotPaidOrder

func CreateOrdersGenerateInvoiceResponse422OrdersGenerateInvoiceNotPaidOrder(notPaidOrder components.NotPaidOrder) OrdersGenerateInvoiceResponse422OrdersGenerateInvoice

func (OrdersGenerateInvoiceResponse422OrdersGenerateInvoice) Error

func (OrdersGenerateInvoiceResponse422OrdersGenerateInvoice) MarshalJSON

func (*OrdersGenerateInvoiceResponse422OrdersGenerateInvoice) UnmarshalJSON

type OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceType

type OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceType string
const (
	OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceTypeMissingInvoiceBillingDetails OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceType = "MissingInvoiceBillingDetails"
	OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceTypeNotPaidOrder                 OrdersGenerateInvoiceResponse422OrdersGenerateInvoiceType = "NotPaidOrder"
)

type PaymentAlreadyInProgress

type PaymentAlreadyInProgress struct {
	Error_ string `const:"PaymentAlreadyInProgress" json:"error"`
	Detail string `json:"detail"`
}

func (*PaymentAlreadyInProgress) Error

func (e *PaymentAlreadyInProgress) Error() string

type PaymentError

type PaymentError struct {
	Error_ string `const:"PaymentError" json:"error"`
	Detail string `json:"detail"`
}

func (*PaymentError) Error

func (e *PaymentError) Error() string

type PaymentFailed

type PaymentFailed struct {
	Error_ string `const:"PaymentFailed" json:"error"`
	Detail string `json:"detail"`
}

func (*PaymentFailed) Error

func (e *PaymentFailed) Error() string

type PaymentMethodInUseByActiveSubscription

type PaymentMethodInUseByActiveSubscription struct {
	Error_ string `const:"PaymentMethodInUseByActiveSubscription" json:"error"`
	Detail string `json:"detail"`
}

func (*PaymentMethodInUseByActiveSubscription) Error

type RefundedAlready

type RefundedAlready struct {
	Error_ string `const:"RefundedAlready" json:"error"`
	Detail string `json:"detail"`
}

func (*RefundedAlready) Error

func (e *RefundedAlready) Error() string

type ResourceNotFound

type ResourceNotFound struct {
	Error_ string `const:"ResourceNotFound" json:"error"`
	Detail string `json:"detail"`
}

func (*ResourceNotFound) Error

func (e *ResourceNotFound) Error() string

type SubscriptionLocked

type SubscriptionLocked struct {
	Error_ string `const:"SubscriptionLocked" json:"error"`
	Detail string `json:"detail"`
}

func (*SubscriptionLocked) Error

func (e *SubscriptionLocked) Error() string

type Unauthorized

type Unauthorized struct {
	Error_ string `const:"Unauthorized" json:"error"`
	Detail string `json:"detail"`
}

func (*Unauthorized) Error

func (e *Unauthorized) Error() string

Jump to